@@ -5,6 +5,19 @@ function(Ulstv,riqv_quer,startOBJ,reshOBJ,quads)
   # get objects
   SKEL  <- startOBJ$stwm1
   Q     <- reshOBJ$Qmat
+  
+  if(all(!is.na(startOBJ$setC)))
+  {
+    
+    bigv <- vector(mode="numeric",length=ncol(Q))
+    
+    bigv[-startOBJ$setC$whichetas] <- Ulstv
+    bigv[startOBJ$setC$whichetas]  <- startOBJ$setC$whichconstant
+    
+    Ulstv <- bigv
+  }
+  
+  
   opp   <- as.vector(Q %*% Ulstv)
   
   relstv <- relist(opp,SKEL)  
